@@ -71,7 +71,7 @@ sub _try_cmd {
     $out
 }
 
-sub _find_cmd {
+sub _find_remote_cmd {
     my ($self, $cmd) = @_;
     # FIXME: be clever!
     return $cmd;
@@ -144,7 +144,8 @@ sub _test_os {
 
 sub _test_os_posix {
     my $self = shift;
-    my $os = $self->_capture_uname('operating_system') // return;
+    my $os = $self->_capture_uname('operating_system') //
+        $self->_capture_uname('kernel_name') // return;
     { os => $os, posix => 1 };
 }
 
@@ -162,7 +163,7 @@ sub _test_shell {
 sub _test_linux_os_release {
     my $self = shift;
     $self->_run_test('os_linux') // return;
-    my $cat = $self->_find_cmd('cat');
+    my $cat = $self->_find_remote_cmd('cat');
     if (my @out = $self->_try_cmd("$cat /etc/os-release")) {
         my %output;
         for (@out) {
